summaryrefslogtreecommitdiff
path: root/tests/test_api.py
diff options
context:
space:
mode:
authorNed Batchelder <ned@nedbatchelder.com>2020-09-12 19:53:31 -0400
committerNed Batchelder <ned@nedbatchelder.com>2020-09-12 19:53:31 -0400
commitc907b2ee1184dbcea1a3698588ad198a32fbea71 (patch)
tree466be547016f5efe52aa8bdf651d26a438a8e142 /tests/test_api.py
parent263f3e1da8e5a6a32056a8697286f9adf0f6a55d (diff)
downloadpython-coveragepy-git-c907b2ee1184dbcea1a3698588ad198a32fbea71.tar.gz
ambigious -> ambiguous
Diffstat (limited to 'tests/test_api.py')
-rw-r--r--tests/test_api.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/tests/test_api.py b/tests/test_api.py
index a28d0133..e2a2a555 100644
--- a/tests/test_api.py
+++ b/tests/test_api.py
@@ -935,20 +935,20 @@ class SourceIncludeOmitTest(IncludeOmitTestsMixin, CoverageTest):
self.filenames_not_in(lines, "p1b")
self.assertEqual(lines['p1c'], 0)
- def test_ambigious_source_package_as_dir(self):
- # pkg1 is a directory and a pkg, since we cd into tests/modules/ambigious
- self.chdir(self.nice_file(TESTS_DIR, 'modules', "ambigious"))
- # pkg1 defaults to directory because tests/modules/ambigious/pkg1 exists
+ def test_ambiguous_source_package_as_dir(self):
+ # pkg1 is a directory and a pkg, since we cd into tests/modules/ambiguous
+ self.chdir(self.nice_file(TESTS_DIR, 'modules', "ambiguous"))
+ # pkg1 defaults to directory because tests/modules/ambiguous/pkg1 exists
lines = self.coverage_usepkgs(source=["pkg1"])
- self.filenames_in(lines, "ambigious")
+ self.filenames_in(lines, "ambiguous")
self.filenames_not_in(lines, "p1a p1b p1c")
- def test_ambigious_source_package_as_package(self):
- # pkg1 is a directory and a pkg, since we cd into tests/modules/ambigious
- self.chdir(self.nice_file(TESTS_DIR, 'modules', "ambigious"))
+ def test_ambiguous_source_package_as_package(self):
+ # pkg1 is a directory and a pkg, since we cd into tests/modules/ambiguous
+ self.chdir(self.nice_file(TESTS_DIR, 'modules', "ambiguous"))
lines = self.coverage_usepkgs(source_pkgs=["pkg1"])
self.filenames_in(lines, "p1a p1b")
- self.filenames_not_in(lines, "p2a p2b othera otherb osa osb ambigious")
+ self.filenames_not_in(lines, "p2a p2b othera otherb osa osb ambiguous")
# Because source= was specified, we do search for unexecuted files.
self.assertEqual(lines['p1c'], 0)